pyparsing.ParseBaseException

Module pyparsing :: Class ParseBaseException |
[frames] | no frames]

# Class ParseBaseException

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  ParseBaseException

Known Subclasses:
  - ParseException
  - , ParseFatalException

base exception class for all parsing runtime exceptions

Instance Methods
__init__(self, pstr, loc=0, msg=None, elem=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__getattr__(self, aname) supported attributes by name are: | source code
__str__(self) str(x) | source code
__repr__(self) repr(x) | source code
markInputline(self, markerString=`'``>!<``'`) Extracts the exception line from the input string, and marks the location of the exception with a special symbol. | source code
__dir__(self) | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, pstr, loc=0, msg=None, elem=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __getattr__(self, aname) (Qualification operator) | source code
supported attributes by name are: lineno - returns the line number of the exception text col - returns the column number of the exception text line - returns the line containing the exception text

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)